unit FormSizeSave;

{
Author:       Juergen Ruemmler
EMail:        medicus@cityweb.de
Version:      1.1. Stamd 26.02.1999
Legal issues: Copyright (C) 1998, 1999 by Juergen Ruemmler
              Brockdorffstr. 27a, 22149 Hamburg, Deutschland

              TFormSizeSave ist Freeware.

Beschreibung:

   TFormSizeSave laedt und speichert den WindowStatus sowie
   Groesse und Position von der Form auf der TFormSizeSave
   plaziert wurde.

   Es werden zwei Proceduren bereitgestellt:

   Save        :   speichert Groesse, Position und Status in der
                   Registerdatenbank.
                   Diese Procedure wird am besten aus dem Ereignis
                   TForm.OnClose aufgerufen.

   Beispiel:

        procedure TForm1.FormClose(Sender: TObject; var Action: TCloseAction);
        begin
          FormSizeSave1.Save;
        end;

   ****************************

   Load        :   laedt die gespeicherte Gre, Position und Status
                   der Form aus der Registerdatenbank.
                   Diese Procedure wird am besten aus dem Ereignis
                   TForm.OnCreate aufgerufen.

   Beispiel:

        procedure TForm1.FormCreate(Sender: TObject);
        begin
          FormSizeSave1.Load;
        end;

   ****************************

   Properties:   Die Properties COMPANY, PRODUCTNAME und SUBKEY werden wie
                 folgt fr die Register-Datenbank als Schluessel genutzt:

                 HKEY_LOCAL_MACHINE\Software\COMPANY\PRODUCTNAME\SUBKEY

                 SaveMode:  smPositionOnly: nur die Position und WindowStatus,
                            nicht die Groesse einer Form werden gesichert oder
                            geladen.
                            smSizeOnly: nur die Groesse und WindowStatus, nicht
                            die Position einer Form werden gesichert oder
                            geladen.
                            smAll: Groesse, Position und WindowStatus werden
                            gesichert oder geladen.

Historie:

  Version    Datum        Kommentar
  -------    ---------    ---------
  1.0        22.08.1998   Basis-Version
  1.1        26.02.1999   SaveMode eingefuehrt
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Registry;

type
  TSaveMode = (smPositionOnly, smSizeOnly, smAll);

  TFormSizeSave = class(TComponent)
  private
    Modus: TSaveMode;
    FCompany: String;
    FProduct: String;
    FSubKey: String;
  public
    procedure Save;
    procedure Load;
  published
    property Company: String Read FCompany Write FCompany;
    property ProductName: String Read FProduct Write FProduct;
    property SubKey: String Read FSubKey Write FSubKey;
    property SaveMode:TSaveMode Read Modus Write Modus;
  end;

procedure Register;

implementation

var
  Reg: TRegistry;

procedure Register;
begin
  RegisterComponents('Win32', [TFormSizeSave]);
end;

procedure TFormSizeSave.Load;
var Key: String;
begin
  Reg:=TRegistry.Create;
  Reg.RootKey:=HKEY_LOCAL_MACHINE;
  Key:='\SOFTWARE\';
  if Trim(FCompany) <> '' then Key:=Key + FCompany;
  if Trim(FProduct) <> '' then Key:=Key + '\' + FProduct;
  if Trim(FSubKey) <> '' then Key:=Key + '\' + FSubKey;
  if Reg.OpenKey(Key, True) then begin
    if (Modus = smAll) or (Modus = smPositionOnly) then begin
      if Reg.ValueExists(TForm(Owner).Name + '.Left') then
        TForm(Owner).Left:=Reg.ReadInteger(TForm(Owner).Name + '.Left');
      if Reg.ValueExists(TForm(Owner).Name + '.Top') then
        TForm(Owner).Top:=Reg.ReadInteger(TForm(Owner).Name + '.Top');
    end;
    if (Modus = smAll) or (Modus = smSizeOnly) then begin
      if Reg.ValueExists(TForm(Owner).Name + '.Width') then
        TForm(Owner).Width:=Reg.ReadInteger(TForm(Owner).Name + '.Width');
      if Reg.ValueExists(TForm(Owner).Name + '.Height') then
        TForm(Owner).Height:=Reg.ReadInteger(TForm(Owner).Name + '.Height');
    end;
    if Reg.ValueExists(TForm(Owner).Name + '.State') then
      TForm(Owner).WindowState:=TWindowState(Reg.ReadInteger(TForm(Owner).Name + '.State'));
  end;
  Reg.Free;
end;

procedure TFormSizeSave.Save;
var Key: String;
begin
  Reg:=TRegistry.Create;
  Reg.RootKey:=HKEY_LOCAL_MACHINE;
  Key:='\SOFTWARE\';
  if Trim(FCompany) <> '' then Key:=Key + FCompany;
  if Trim(FProduct) <> '' then Key:=Key + '\' + FProduct;
  if Trim(FSubKey) <> '' then Key:=Key + '\' + FSubKey;
  if Reg.OpenKey(Key, True) then begin
    if TForm(Owner).WindowState = wsNormal then begin
      if (Modus = smAll) or (Modus = smPositionOnly) then begin
        Reg.WriteInteger(TForm(Owner).Name + '.Left', TForm(Owner).Left);
        Reg.WriteInteger(TForm(Owner).Name + '.Top', TForm(Owner).Top);
      end;
      if (Modus = smAll) or (Modus = smSizeOnly) then begin
        Reg.WriteInteger(TForm(Owner).Name + '.Width', TForm(Owner).Width);
        Reg.WriteInteger(TForm(Owner).Name + '.Height', TForm(Owner).Height);
      end;
    end;
    Reg.WriteString(TForm(Owner).Name + '.Caption', TForm(Owner).Caption);
    Reg.WriteInteger(TForm(Owner).Name + '.State', Ord(TForm(Owner).WindowState))
  end;
  Reg.Free;
end;

end.
